@@ -1,8 +1,10 @@
 package Courriel::Builder;
-$Courriel::Builder::VERSION = '0.36';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.37';
+
 use Carp qw( croak );
 use Courriel;
 use Courriel::Header::ContentType;
@@ -62,6 +64,7 @@ use Sub::Exporter -setup => {
         my @attachments;
 
         for my $p (@_) {
+            ## no critic (ControlStructures::ProhibitCascadingIfElse)
             if ( $p->{header} ) {
                 push @headers, @{ $p->{header} };
             }
@@ -94,7 +97,7 @@ use Sub::Exporter -setup => {
         else {
             $body_part = first {defined} $plain_body, $html_body;
 
-            croak "Cannot call build_email without a plain or html body"
+            croak 'Cannot call build_email without a plain or html body'
                 unless $body_part;
         }
 
@@ -125,7 +128,7 @@ use Sub::Exporter -setup => {
 }
 
 sub _bad_value {
-    croak "A weird value was passed to build_email: "
+    croak 'A weird value was passed to build_email: '
         . Devel::PartialDump->new()->dump( $_[0] );
 }
 
@@ -136,9 +139,8 @@ sub _add_required_headers {
 
     unless ( $keys{date} ) {
         push @{$headers},
-            (
-            Date => DateTime::Format::Mail->format_datetime( DateTime->now() )
-            );
+            ( Date =>
+                DateTime::Format::Mail->format_datetime( DateTime->now() ) );
     }
 
     unless ( $keys{'message-id'} ) {
@@ -331,7 +333,8 @@ sub attach {
         : @_;
 
     return {
-        attachment => $p{file} ? _part_for_file(%p) : _part_for_content(%p) };
+        attachment => $p{file} ? _part_for_file(%p) : _part_for_content(%p)
+    };
 }
 
 my $flm = File::LibMagic->new();
@@ -402,12 +405,14 @@ my $flm = File::LibMagic->new();
 sub _content_type {
     my $type = shift;
 
-    return Courriel::Header::ContentType->new( mime_type => 'application/unknown' )
+    return Courriel::Header::ContentType->new(
+        mime_type => 'application/unknown' )
         unless defined $type;
 
     my ( $mime_type, $attr ) = parse_header_with_attributes($type);
 
-    return Courriel::Header::ContentType->new( mime_type => 'application/unknown' )
+    return Courriel::Header::ContentType->new(
+        mime_type => 'application/unknown' )
         unless defined $mime_type && length $mime_type;
 
     return Courriel::Header::ContentType->new(
@@ -454,7 +459,7 @@ Courriel::Builder - Build emails with sugar
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -714,7 +719,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
