@@ -1,9 +1,11 @@
 package Courriel::Header;
-$Courriel::Header::VERSION = '0.35';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.37';
+
 use Courriel::Helpers qw( fold_header );
 use Courriel::Types qw( NonEmptyStr Str Streamable );
 use Encode qw( encode find_encoding );
@@ -64,6 +66,8 @@ sub as_string {
 {
     my $header_chunk = qr/
                              (?:
+                                 ^
+                             |
                                  (?<ascii>[\x21-\x7e]+)   # printable ASCII (excluding space, \x20)
                              |
                                  (?<non_ascii>\S+)        # anything that's not space
@@ -105,7 +109,9 @@ sub as_string {
                 push @values, q{ } if $chunks[ $i + 1 ];
             }
             else {
-                push @values, $chunks[$i]{ascii} . ( $chunks[$i]{ws} // q{} );
+                push @values,
+                    ( $chunks[$i]{ascii} // q{} )
+                    . ( $chunks[$i]{ws}  // q{} );
             }
         }
 
@@ -129,7 +135,7 @@ sub _mime_encode {
 
     my @result;
     my $chunk = q{};
-    while ( length( my $chr = substr( $text, 0, 1, '' ) ) ) {
+    while ( length( my $chr = substr( $text, 0, 1, q{} ) ) ) {
         my $chr = encode( $charset, $chr, 0 );
 
         if ( length($chunk) + length($chr) > $real_length ) {
@@ -162,7 +168,7 @@ Courriel::Header - A single header's name and value
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -217,13 +223,9 @@ This class does the C<Courriel::Role::Streams> role.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
