@@ -1,9 +1,11 @@
 package Courriel::Header::Disposition;
-$Courriel::Header::Disposition::VERSION = '0.34';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.37';
+
 use Courriel::Types qw( Bool Maybe NonEmptyStr );
 use DateTime;
 use DateTime::Format::Mail;
@@ -14,7 +16,8 @@ use MooseX::StrictConstructor;
 
 extends 'Courriel::Header';
 
-with 'Courriel::Role::HeaderWithAttributes' => { main_value_key => 'disposition' };
+with 'Courriel::Role::HeaderWithAttributes' =>
+    { main_value_key => 'disposition' };
 
 has '+value' => (
     required => 0,
@@ -53,7 +56,7 @@ has filename => (
         exists $_[0]->_attributes()->{filename}
             ? $_[0]->_attributes()->{filename}->value()
             : undef;
-    }
+    },
 );
 
 {
@@ -110,7 +113,7 @@ Courriel::Header::Disposition - The content disposition for an email part
 
 =head1 VERSION
 
-version 0.34
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -250,19 +253,15 @@ This class extends L<Courriel::Header>.
 
 =head1 ROLES
 
-This class does the L<Courriel::Role::HeaderWithAttributes> role.
+This class does the C<Courriel::Role::HeaderWithAttributes> role.
 
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
