@@ -1,9 +1,11 @@
 package Courriel::HeaderAttribute;
-$Courriel::HeaderAttribute::VERSION = '0.35';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.37';
+
 use Courriel::HeaderAttribute;
 use Courriel::Helpers qw( quote_and_escape_attribute_value );
 use Courriel::Types qw( Maybe NonEmptyStr Str );
@@ -50,12 +52,14 @@ override BUILDARGS => sub {
     return $p;
 };
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _stream_to {
     my $self   = shift;
     my $output = shift;
 
     $output->( $self->_as_string() );
 }
+## use critic
 
 {
     my $non_attribute_char = qr{
@@ -116,6 +120,7 @@ sub _stream_to {
     }
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _simple_parameter {
     my $self  = shift;
     my $order = shift;
@@ -157,14 +162,14 @@ sub _encoded_parameter {
     # XXX (1) - does it makes sense to just say everything is utf-8? in theory
     # someone could pass through binary data in another encoding.
     unless ($order) {
-        $param .= 'UTF-8' . q{'}
-            . ( $self->language() // q{} ) . q{'};
+        $param .= 'UTF-8' . q{'} . ( $self->language() // q{} ) . q{'};
     }
 
     $param .= $value;
 
     return $param;
 }
+## use critic;
 
 __PACKAGE__->meta()->make_immutable();
 
@@ -182,7 +187,7 @@ Courriel::HeaderAttribute - A single attribute belonging to a header
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -266,13 +271,9 @@ This class does the C<Courriel::Role::Streams> role.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
