@@ -1,9 +1,11 @@
 package Courriel::Part::Single;
-$Courriel::Part::Single::VERSION = '0.35';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.37';
+
 use Courriel::Header::Disposition;
 use Courriel::Types qw( NonEmptyStr StringRef );
 use Email::MIME::Encodings;
@@ -124,10 +126,6 @@ sub _maybe_set_disposition_in_headers {
 
 sub is_multipart {0}
 
-sub _default_mime_type {
-    return 'text/plain';
-}
-
 {
     my %unencoded = map { $_ => 1 } qw( 7bit 8bit binary );
 
@@ -146,7 +144,8 @@ sub _default_mime_type {
 
         return \$bytes if $self->content_type()->is_binary();
 
-        return \$bytes if lc $self->content_type()->charset() eq 'unknown-8bit';
+        return \$bytes
+            if lc $self->content_type()->charset() eq 'unknown-8bit';
 
         return \(
             decode(
@@ -186,12 +185,14 @@ sub encoded_content {
     return ${ $_[0]->encoded_content_ref() };
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _stream_content {
     my $self   = shift;
     my $output = shift;
 
     return $output->( $self->encoded_content() );
 }
+## use critic
 
 __PACKAGE__->meta()->make_immutable();
 
@@ -209,7 +210,7 @@ Courriel::Part::Single - A part which does not contain other parts, only content
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -238,8 +239,8 @@ This method creates a new part object. It accepts the following parameters:
 
 =item * content
 
-This can either be a string or a reference to a scalar. It should be in Perl's
-native utf-8 encoding and I<not> a byte string.
+This can either be a string or a reference to a scalar. It should be a character
+string, I<not> a byte string.
 
 If you pass a reference, then the scalar underlying the reference may be
 modified, so don't pass in something you don't want modified.
@@ -359,20 +360,16 @@ See the C<as_string()> method for documentation on the C<charset> parameter.
 
 =head1 ROLES
 
-This class does the C<Courriel::Role::Part> and L<Courriel::Role::Streams>
+This class does the C<Courriel::Role::Part> and C<Courriel::Role::Streams>
 roles.
 
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
