@@ -1,9 +1,11 @@
 package Courriel::Role::Part;
-$Courriel::Role::Part::VERSION = '0.36';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.37';
+
 use Courriel::Header::ContentType;
 use Courriel::Header::Disposition;
 use Courriel::Types qw( NonEmptyStr );
@@ -12,7 +14,7 @@ use Moose::Role;
 
 with 'Courriel::Role::Streams';
 
-requires qw( _default_mime_type _stream_content );
+requires qw( _stream_content );
 
 has headers => (
     is       => 'rw',
@@ -61,6 +63,7 @@ sub _maybe_set_content_type_in_headers {
     $self->headers()->replace( 'Content-Type' => $self->content_type() );
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _stream_to {
     my $self   = shift;
     my $output = shift;
@@ -71,6 +74,7 @@ sub _stream_to {
 
     return;
 }
+## use critic;
 
 {
     my $fake_ct = Courriel::Header::ContentType->new_from_value(
