@@ -1,9 +1,11 @@
 package Courriel::Types::Internal;
-$Courriel::Types::Internal::VERSION = '0.35';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.37';
+
 use List::AllUtils qw( all );
 use Scalar::Util qw( blessed );
 
@@ -20,7 +22,8 @@ use MooseX::Types -declare => [
         )
 ];
 use MooseX::Types::Common::String qw( NonEmptyStr );
-use MooseX::Types::Moose qw( ArrayRef CodeRef FileHandle HashRef Object ScalarRef Str );
+use MooseX::Types::Moose
+    qw( ArrayRef CodeRef FileHandle HashRef Object ScalarRef Str );
 
 #<<<
 subtype Body,
@@ -49,7 +52,9 @@ my $_check_header_array = sub {
         }
     }
 
+    ## no critic (ControlStructures::ProhibitNegativeExpressionsInUnlessAndUntilConditions)
     return 0 unless all { defined $_ && length $_ && !ref $_ } @{$_}[@even];
+    ## use critic;
     return 0
         unless all { blessed($_) && $_->isa('Courriel::Header') } @{$_}[@odd];
 
@@ -76,7 +81,7 @@ coerce Streamable,
     from FileHandle,
     via sub {
         my $fh = $_;
-        return sub { print {$fh} @_ };
+        return sub { print {$fh} @_ or die $! };
     };
 
 coerce Streamable,
