@@ -1,8 +1,10 @@
 package Email::Abstract::Courriel;
-$Email::Abstract::Courriel::VERSION = '0.35';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.37';
+
 use Courriel;
 
 use parent 'Email::Abstract::Plugin';
@@ -55,7 +57,7 @@ Email::Abstract::Courriel - Email::Abstract wrapper for Courriel
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 DESCRIPTION
 
@@ -72,13 +74,9 @@ L<Email::Abstract>, L<Courriel>.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
